/**
 * The nodereference explorer javascript file.
 * It assigns actions to the widget buttons and draws the
 * dialog. It contains several other fixes now (see code comments).
 * All setting are indexed for multiple values per widget yet.
 */

//define name space
Drupal.nodereference_explorer = function() {};

//main function which receives settings from the server
Drupal.behaviors.nodereference_explorer = function(context) {
	
	Drupal.nodereference_explorer.actions(); //buttons, preview
	Drupal.nodereference_explorer.selection(); //selection of view items
	
	//FIX: When title filters are exposed there is naming conflict with the
	//node's title field. Firefox just hides the node title field.
	//No other collision are known yet.
	$('#edit-title-wrapper').attr('style', 'display:true');
}

/**
 * Widget actions
 */
Drupal.nodereference_explorer.actions = function() {
	
	var ids = Drupal.settings.nodereference_explorer.ids;
	
	//tab behaviours
	Drupal.nodereference_explorer.actions.tabs(ids);
	
	//attach behaviour to browse buttons
	$(ids['browse']).each(function (index, browse) {
		$('#'+browse).click(function() {
			Drupal.nodereference_explorer.unmask_title();
			Drupal.nodereference_explorer.actions.browse(index, ids);
		});
	});
	
	//attach behaviour to remove buttons
	$(ids['remove']).each(function (index, remove) {
		$('#'+remove).click(function() {	
			Drupal.nodereference_explorer.actions.remove(index, ids);
		});
	});
	
	//attach behaviour to autocomplete buttons
	$(ids['autocomplete']).each(function (index, autocomplete) {
		$('#'+autocomplete).change(function() {
			Drupal.nodereference_explorer.actions.autocomplete(index, ids, this);
		});
	});
}

/**
 * By clicking the browse button open the dialog
 */
Drupal.nodereference_explorer.actions.browse = function(index, ids) {
	
	var dialog = Drupal.settings.nodereference_explorer.dialog;
	var actions = Drupal.settings.nodereference_explorer.actions;
	
	var dialogClasses = $('#'+ids['dialog'][index]).attr('class');
	
	//set the cache
	$selected = $('#'+ids['autocomplete'][index]).val();
	$('#'+ids['cache'][index]).attr('value', $selected);
	
	//visually select a view item
	$('.viewItemSelected').removeClass('viewItemSelected');
	$('.views-item-selectable[title="'+$selected+'"]').addClass('viewItemSelected');
	
	//initialize dialog
	if (dialogClasses.indexOf('ui-dialog-content') == -1) {	
		
		Drupal.nodereference_explorer.unmask_title();
		
		$('#'+ids['dialog'][index]).dialog(dialog);
		$('#'+ids['dialog'][index]).data("modal.dialog", true);
		$('#'+ids['dialog'][index]).data("autoOpen.dialog", false);
		
		$ok = actions['ok'];
		$cancel = actions['cancel'];
		$actions = {};
		
		
		//when click ok this happens
		$actions[$ok] = function() {
			
			Drupal.nodereference_explorer.mask_title();	
			
			var title = $('.viewItemSelected').attr('title');
			$('#'+ids['autocomplete'][index]).val(title);
			
			var delimit = '[nid:';
			$start = title.indexOf(delimit)+delimit.length;
			$nid = title.substring($start, title.length-1);
			
			$('#'+ids['change'][index]).attr('value', $nid);
			$('#'+ids['change'][index]).trigger('change');
			
			$('#'+ids['dialog'][index]).dialog('close');
		};
		
		//when canceling the dialog this happens
		$actions[$cancel] = function() { 
			$('#'+ids['dialog'][index]).dialog('close');
			Drupal.nodereference_explorer.mask_title();
		};
		$('#'+ids['dialog'][index]).data("buttons.dialog", $actions);
		$('#'+ids['dialog'][index]).show(); //unhide dialog
		
		//when dialog closes this happens
		$('#'+ids['dialog'][index]).bind('dialogclose', function(event) {
			Drupal.nodereference_explorer.mask_title();
		 });

	}
	$('#'+ids['dialog'][index]).dialog('open'); //open the dialog
}

/**
 * Remove button action
 */
Drupal.nodereference_explorer.actions.remove = function(index, ids) {
	$('#'+ids['autocomplete'][index]).val('');
	$('#'+ids['preview'][index]).text('');
}

Drupal.nodereference_explorer.actions.autocomplete = function(index, ids, autocompleteElement) {
	var val = $(autocompleteElement).val();
	var start = val.indexOf('[nid:')+5;
	var end = val.length-1;
	$nid = val.substring(start, end);
	//alert($nid + ', '+$('#'+ids['change'][index]).val());
	//only trigger when values are different
	if ($nid != $('#'+ids['change'][index]).val()) {
		$('#'+ids['change'][index]).val($nid);
		$('#'+ids['change'][index]).trigger('change');
	}
}

/**
 * Tab related events, e. g. show/hide filter a form or 
 * render the initial display
 */
Drupal.nodereference_explorer.actions.tabs = function(ids) {
	//render dialog tabs
	$(ids['tabs']).each(function (index, tab) { //TODO: add options for tab initialization here.
		$('#'+tab +' > ul').tabs(); //{ fx: { opacity: "toggle" }} );
	});
	
	//display filter for selected tab
	$('.nodereference-explorer-dialog-tabs-tab > a').click(function() {
		$('.nodereference-explorer-views-filters').attr('style', 'display:none');
		var href = $(this).attr('href');
		$display = href.substring(1); //alert($display);
		$('#nodereference-explorer-views-filters-'+$display).attr('style', 'display:true');
	});
}

/**
 * 
 */
Drupal.nodereference_explorer.selection = function() {
	
	//fix for hover over active table cell (column sorted)
	$('.views-item-selectable').mouseover(function() {
		$background = $(this).css('background-color'); //'background');
		//alert($background);
		$('td', this).css('background-color', $background);
	}).mouseout(function() {
		$('td', this).css('background-color', '');
	});
	
	
	//before sorting or paging
	$('a.active').click(function() {
		$title = $('.viewItemSelected').attr('title');
		$('.nodereference-explorer-dialog-views-selection-cache').attr('value', $title);
		//alert('Before submit');
	}).ready(function() { //after paging or sorting
		$title = $('.nodereference-explorer-dialog-views-selection-cache').attr('value');
		$('.views-item-selectable[title="'+$title+'"]').addClass('viewItemSelected');
	});
	
	//select view item visually
	$('.views-item-selectable').click(function() {
		$('.viewItemSelected').toggleClass('viewItemSelected');
		$(this).toggleClass('viewItemSelected');
		$(this).siblings().removeClass('viewItemSelected');
		
		$title = $(this).attr('title');
		$('.views-item-selectable[title="'+$title+'"]').addClass('viewItemSelected');
	});
}

/**
 * Mask the dialog title filter form widgets
 * Helper function for fixing the collision between the filter form's title
 * and the node title
 */
Drupal.nodereference_explorer.mask_title = function () {
	$('.views-widget > #edit-title-wrapper > #edit-title').attr('name', 'title-masked');
	$('.views-widget > #edit-title-wrapper > #edit-title').attr('id', 'edit-title-masked');
}

/**
 * Unmask the dialog title filter form widgets
 * Helper function for fixing the collision between the filter form's title
 * and the node title
 */
Drupal.nodereference_explorer.unmask_title = function () {
	$('.views-widget > #edit-title-wrapper > #edit-title-masked').attr('name', 'title');
	$('.views-widget > #edit-title-wrapper > #edit-title-masked').attr('id', 'edit-title');
}

