<?php
/**
 * @file nodereference-explorer-view-table-selectable.tpl.php
 * Template to display a view as a table with selectable rows.
 *
 * - $title : The title of this group of rows.  May be empty.
 * - $header: An array of header labels keyed by field id.
 * - $fields: An array of CSS IDs to use for each field id.
 * - $class: A class or classes to apply to the table, based on settings.
 * - $rows: An array of row items. Each row is an array of content
 *   keyed by field ID.
 * - $selectable: View item class for marking a selectable entity
 * @ingroup views_templates
 *
 * Each row array has to have a node id (nid) and a title. These properties must
 * be provided as view fields because they rendered into the title attribute of
 * each table row. Otherwise the row will not be selectable.
 */
if (!isset($class)) $class = 'views-table';
if (!isset($selectable)) $selectable = 'views-item-selectable';
?>
<table class="<?php print $class; ?>">
  <?php if (!empty($title)) : ?>
    <caption><?php print $title; ?></caption>
  <?php endif; ?>
  <thead>
    <tr>
      <?php foreach ($header as $field => $label): ?>
        <th class="views-field views-field-<?php print $fields[$field]; ?>">
          <?php print $label; ?>
        </th>
      <?php endforeach; ?>
    </tr>
  </thead>
  <tbody>
    <?php foreach ($rows as $count => $row): ?>
      <tr class="<?php print $selectable; ?> <?php print ($count % 2 == 0) ? 'even' : 'odd';?>"
      <?php if (isset($row['title']) && isset($row['nid'])): ?>
      	  title="<?php print $row['title'] . ' [nid:'. $row['nid'] .']';?>"<?php endif; ?>>
        <?php foreach ($row as $field => $content): ?>
          <td class="views-field views-field-<?php print $fields[$field]; ?>">
            <?php print $content; ?>
          </td>
        <?php endforeach; ?>
      </tr>
    <?php endforeach; ?>
  </tbody>
</table>
