<?php

/**
 * @file theme.inc
 * Template preprocess function for preparing necessary template variables and doing
 * theme related tasks.
 */

/**
 * Prepare the dialog template variables and add css,
 * as well as javascript and javascript settings
 * @param $vars template variables
 */
function template_preprocess_nodereference_explorer_dialog(&$vars) {

  //get the handler object
  $vars['handler'] = $vars['element']['#handler'];
  $vars['dialog'] = $vars['handler']->get_options('dialog'); //retrieve dialog settings


  $theme = $vars['handler']->get_options('theme'); //get theme/css settings

  //jquery_ui theme
  if (isset($theme['css']) && $theme['css'] != '') {
    drupal_add_css(JQUERY_UI_PATH . '/themes/'.$theme['css']); //overall dialog window
  }
  else { //no custom css specified, either global or module (local) theme
    if (isset($vars['dialog']['dialogClass']) && $vars['dialog']['dialogClass'] == '') { //no css scope specified, load local module css
      nodereference_explorer_add_css('selection');
      nodereference_explorer_add_css('dialog');
      nodereference_explorer_add_css('form');
      nodereference_explorer_add_css('tabs');
     // nodereference_explorer_add_css('view');
    }
    else { //css scope specified
      //do nothing
      //load global css by specified css scope (done automatically by css scope)
    }
  }

  //add dialog related js files
  $jq_ui_files = array('ui.dialog', 'ui.tabs');

  if ($vars['dialog']['draggable']) //can the dialog window be moved
    array_push($jq_ui_files, 'ui.draggable');

  if ($vars['dialog']['resizable']) //can the dialog window be resized
    array_push($jq_ui_files, 'ui.resizable');

  if ($vars['dialog']['bgiframe']) //patch for IE 6 z-Index problem, i. e. overlay of controls over dialog
    nodereference_explorer_add_js('jquery.bgiframe', true);
    jquery_ui_add($jq_ui_files);

  //custom action and selection js
  nodereference_explorer_add_js('explorer');

  //add javascript settings only once
  static $settings;

  if ($settings == null) {
    $settings['dialog'] = $vars['dialog'];
    $settings['actions'] = $vars['handler']->get_options('actions');
    $settings['ids'] = $vars['handler']->ids;
    drupal_add_js(
      array(NODE_REFERENCE_EXPLORER_MODULE_NAME
       => $settings,
     ),
  	'setting'
    );
  }
}

/**
 * Theme autocomplete widget
 * @param $element widget
 * @return rendered representation of autocomplete
 */
function theme_nodereference_explorer($element) {
  return $element['#children'];
}

/**
 * Template for selectable row fields. This is used by grid,
 * list and unformatted view plugins.
 * @param $vars template variables
 */
function template_preprocess_nodereference_explorer_view_row_fields_selectable(&$vars) {
  template_preprocess_views_view_fields($vars);
}

/**
 * Template for selectable tables.
 * @param $vars template variables
 */
function template_preprocess_nodereference_explorer_view_table_selectable(&$vars) {
  template_preprocess_views_view_table($vars);
}